==> inspect-api-0.0.61-20250811.034517-2-sources.jar: com/tll/inspect/rpc/vo/travel/CrossStoreInfoRpcVO.java <==
package com.tll.inspect.rpc.vo.travel;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 门店信息
 *
 * @author zhaoshuai
 * @date 2025/6/6
 */
@Data
@ApiModel(description = "门店信息")
public class CrossStoreInfoRpcVO implements Serializable {

    private static final long serialVersionUID = -810460531635691420L;

    @ApiModelProperty(value = "门店id", position = 1)
    private Long id;

    @ApiModelProperty(value = "欠款订单编号")
    private String businessOrderNumber;

    @ApiModelProperty(value = "欠款类型名称")
    private String arrearsTypeName;

    @ApiModelProperty(value = "门店ID")
    private String storeName;

    @ApiModelProperty(value = "门店编码")
    private String storeCode;

    @ApiModelProperty(value = "法人姓名")
    private String legalPerson;

    @ApiModelProperty(value = "法人电话")
    private String legalPersonPhone;

    @ApiModelProperty(value = "法人身份证号")
    private String legalPersonIdCard;

    @ApiModelProperty(value = "法人联系地址")
    private String legalPersonAddress;

    @ApiModelProperty(value = "房租（万/年）")
    private String rent;

    @ApiModelProperty(value = "区域经理")
    private String areaManager;

    @ApiModelProperty(value = "门店地址")
    private String storeAddress;

    @ApiModelProperty(value = "运营状态：0：签约、1：营业中、2：短期闭店、3：空合同、4：到期解约、5：长期闭店、7：待装修、8：强制解约、9：其它解约")
    private Integer operationStatus;

    @ApiModelProperty(value = "门店类型：1：加盟店  0：直营店")
    private Integer storeType;

    @ApiModelProperty(value = "省")
    private String province;

    @ApiModelProperty(value = "市")
    private String city;

    @ApiModelProperty(value = "区")
    private String district;

    @ApiModelProperty(value = "登记人")
    private String registrant;

    @ApiModelProperty(value = "sap编码")
    private String sapCode;

    @ApiModelProperty(value = "最近一次巡检时间")
    private String lastInspectTime;

    @ApiModelProperty(value = "最近一次巡检单号")
    private Long lastInspectReportId;

    @ApiModelProperty(value = "最近一次报货时间")
    private String lastDeliveryTime;

    @ApiModelProperty(value = "最近一次配比考试得分")
    private BigDecimal lastExamScore;

    @ApiModelProperty("最近一次巡检得分")
    private BigDecimal lastInspectScore;

    @ApiModelProperty("排序权重:未计划门店>已计划门店>已巡门店,对应1-3")
    private Integer sortWeight;

    @ApiModelProperty("门店是否已签到")
    private Boolean storeSigned = false;

    @ApiModelProperty("门店计划巡检时间")
    private String storePlanDate;

    @ApiModelProperty("是否已绑定行程（是否已计划待巡）（0未绑定/1已绑定）")
    private Boolean bindingTravel;
}

==> inspect-api-1.0.19-20251111.050536-2-sources.jar: com/tll/inspect/rpc/vo/travel/CrossStoreInfoRpcVO.java <==
package com.tll.inspect.rpc.vo.travel;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Set;

/**
 * 门店信息
 *
 * @author zhaoshuai
 * @date 2025/6/6
 */
@Data
@ApiModel(description = "门店信息")
public class CrossStoreInfoRpcVO implements Serializable {

    private static final long serialVersionUID = -810460531635691420L;

    @ApiModelProperty(value = "门店id", position = 1)
    private Long id;

    @ApiModelProperty(value = "欠款订单编号")
    private String businessOrderNumber;

    @ApiModelProperty(value = "欠款类型名称")
    private String arrearsTypeName;

    @ApiModelProperty(value = "门店ID")
    private String storeName;

    @ApiModelProperty(value = "门店编码")
    private String storeCode;

    @ApiModelProperty(value = "法人姓名")
    private String legalPerson;

    @ApiModelProperty(value = "法人电话")
    private String legalPersonPhone;

    @ApiModelProperty(value = "法人身份证号")
    private String legalPersonIdCard;

    @ApiModelProperty(value = "法人联系地址")
    private String legalPersonAddress;

    @ApiModelProperty(value = "房租（万/年）")
    private String rent;

    @ApiModelProperty(value = "区域经理")
    private String areaManager;

    @ApiModelProperty(value = "门店地址")
    private String storeAddress;

    @ApiModelProperty(value = "运营状态：0：签约、1：营业中、2：短期闭店、3：空合同、4：到期解约、5：长期闭店、7：待装修、8：强制解约、9：其它解约")
    private Integer operationStatus;

    @ApiModelProperty(value = "门店类型：1：加盟店  0：直营店")
    private Integer storeType;

    @ApiModelProperty(value = "省")
    private String province;

    @ApiModelProperty(value = "市")
    private String city;

    @ApiModelProperty(value = "区")
    private String district;

    @ApiModelProperty(value = "登记人")
    private String registrant;

    @ApiModelProperty(value = "sap编码")
    private String sapCode;

    @ApiModelProperty(value = "最近一次巡检时间")
    private String lastInspectTime;

    @ApiModelProperty(value = "最近一次巡检单号")
    private Long lastInspectReportId;

    @ApiModelProperty(value = "最近一次报货时间")
    private String lastDeliveryTime;

    @ApiModelProperty(value = "最近一次配比考试得分")
    private BigDecimal lastExamScore;

    @ApiModelProperty("最近一次巡检得分")
    private BigDecimal lastInspectScore;

    @ApiModelProperty("排序权重:未计划门店>已计划门店>已巡门店,对应1-3")
    private Integer sortWeight;

    @ApiModelProperty("门店是否已签到")
    private Boolean storeSigned = false;

    @ApiModelProperty("门店计划巡检时间")
    private String storePlanDate;

    @ApiModelProperty("门店计划巡检时间")
    private Set<String> storePlanDates;

    @ApiModelProperty("行程id")
    private Long travelId;
//    @ApiModelProperty("是否已绑定行程（是否已计划待巡）（0未绑定/1已绑定）")
//    private Boolean bindingTravel;
//    @ApiModelProperty("绑定行程id")
//    private Long bindingTravelId;
}
